@@ -18,7 +18,7 @@ class sanity_check:
 
       self.cur_model  = model
       self.cur_rate = 0
-      
+      self.df = pd.DataFrame()
       model_dict = {}
       loss_record = {}
       lr_list  = []
@@ -38,7 +38,7 @@ class sanity_check:
     
     for x in self.loss_record.keys():
       print('learning_Rate : ',x)
-      self.cur_rate = int(x)
+      self.cur_rate = float(x)
       K.set_value(self.model.optimizer.lr, self.cur_rate)
 
       batchcallback = LambdaCallback(on_batch_end=lambda batch,
@@ -57,6 +57,10 @@ class sanity_check:
     verbose = 2)
       
       #print(self.history.history['val_loss'])
+      epoch_list = [i for i in range(epochs)]
+      learn_list = [x for i in range(epochs)]
+      lr_df = pd.DataFrame({'epochs':epoch_list,'lr_rate':learn_list,'val_loss':list(self.history.history['val_loss'])})
+      self.df = pd.concat([self.df,lr_df])
       self.loss_record[x] = self.history.history['val_loss']
       K.clear_session()
 
